<?php
/**
 * Jeg Front Preview Render Single Post
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package JFP_WOOCOMMERCE\Single
 */

namespace JFP_WOOCOMMERCE\Single;

use JFP_WOOCOMMERCE\Elements\Elements_Manager;
use WP_Post;

/** Exit if accessed directly */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Class Single_Post
 *
 * @package JFP_WOOCOMMERCE\Single
 */
class Single_Post {

	/**
	 * Post ID
	 *
	 * @var WP_Post
	 */
	private $post_id;

	/**
	 * Post Type
	 *
	 * @var WP_Post
	 */
	private $post_type;

	/**
	 * Post Content
	 *
	 * @var string
	 */
	private $post_content;

	/**
	 * @var Elements_Manager
	 */
	private $manager;

	/**
	 * Single_Post constructor.
	 */
	public function __construct() {
		$this->elements_instance();
		$this->hook();
	}

	/**
	 * Set Post data
	 */
	public function set_post_data() {
		global $post;
		$this->post_type    = $post->post_type;
		$this->post_id      = $post->ID;
		$this->post_content = $post->post_content;
	}

	/**
	 * Add font Preview to the content.
	 */
	private function hook() {
		add_action( 'template_redirect', [ $this, 'set_post_data' ] );

		// Integration WooCommerce.
		add_filter( 'woocommerce_product_tabs', [ $this, 'register_product_tab' ] );
		add_action( 'woocommerce_product_font_preview', [ $this, 'wc_render_font_preview' ] );
	}

	/**
	 * Render Font Preview on WooCommerce
	 */
	public function wc_render_font_preview() {
		echo $this->render_preview();
	}

	/**
	 * Register Font Preview product tab
	 *
	 * @param $tabs
	 *
	 * @return mixed
	 */
	public function register_product_tab( $tabs ) {
		if ( jfp_woocommerce_preview_is_active( $this->post_id ) ) {
			$tabs['font_preview'] = [
				'title'    => esc_attr__( 'Font Preview', 'jfp-woocommerce' ),
				'priority' => 1,
				'callback' => [ $this, 'get_product_tab' ],
				/** @uses get_product_tab */
			];
		}

		return $tabs;
	}

	private function elements_instance() {
		$this->manager = new Elements_Manager();
	}

	/**
	 * Render Font Preview
	 *
	 * @param string $content Content from 'the_content'.
	 *
	 * @param null   $id
	 *
	 * @return string
	 */
	public function render_preview( $content = '', $post_id = null ) {
		$id           = null === $post_id ? $this->post_id : $post_id;
		$font_preview = '';
		if ( jfp_woocommerce_preview_is_active( $id ) ) {
			$attr               = [];
			$font_lists         = jeg_metabox( 'jfp-woocommerce-settings.fonts', [], $id );
			$placeholder        = jeg_metabox( 'jfp-woocommerce-settings.placeholder', '', $id );
			$font_size          = jeg_metabox( 'jfp-woocommerce-settings.font_size', 24, $id );
			$min_font_size      = jeg_metabox( 'jfp-woocommerce-settings.min_font_size', 4, $id );
			$max_font_size      = jeg_metabox( 'jfp-woocommerce-settings.max_font_size', 240, $id );
			$font_color         = jeg_metabox( 'jfp-woocommerce-settings.font_color', '#000000', $id );
			$background_color   = jeg_metabox( 'jfp-woocommerce-settings.background_color', '#FFFFFF', $id );
			$background_opacity = jeg_metabox( 'jfp-woocommerce-settings.background_opacity', 100, $id );

			$attr['fonts']              = $font_lists;
			$attr['placeholder']        = $placeholder;
			$attr['font_size']          = $font_size;
			$attr['min_font_size']      = $min_font_size;
			$attr['max_font_size']      = $max_font_size;
			$attr['font_color']         = $font_color;
			$attr['background_color']   = $background_color;
			$attr['background_opacity'] = $background_opacity;
			$this->manager->set_attr( $attr );
			$font_preview = $this->manager->build_element();
		}
		if ( ! empty( $font_preview ) ) {
			$content .= $font_preview;
		}

		return $content;
	}

	/**
	 * Get Product Tab
	 */
	public function get_product_tab() {
		jfp_woocommerce_get_template_part( '/fragment/woocommerce/single-product/tabs/font-preview' );
	}


}
